import React from "react";
import { shallow } from "enzyme";
import mount from "enzyme/build/mount";
import { waitFor } from "@testing-library/react";

import NestedDeleteTeamDialog from "../../components/NestedDeleteTeamDialog";
import TeamList from "../../components/TeamList";
import AddTeamDialog from "../../components/AddTeamDialog";

describe("Test Case For App", () => {
  it("should render TextField", () => {
    const wrapper = shallow(<TeamList teams={[]} setTeams={[]} />);
    const textElement = wrapper.find("#Search-bar");
    expect(textElement).toHaveLength(1);
  });
});

it("accepts ListItemText props", () => {
  const wrapper = mount(
    <NestedDeleteTeamDialog
      dialogTitle="Test Dialogue Title"
      listName="LIST NAME"
    />
  );
  expect(wrapper.props().dialogTitle).toEqual("Test Dialogue Title");
  expect(wrapper.props().listName).toEqual("LIST NAME");
});

describe("Check error button attributes on NestedDeleteTeamDialog", () => {
  it("should be error", () => {
    const wrapper = mount(
      <NestedDeleteTeamDialog
        openDialog={[]}
        setOpenDialog={[]}
        dialogTitle={[]}
        deleteTeamFunc={[]}
        listName={[]}
      />
    );
    const button = wrapper.find("#error-button");
    // wait for them to render
    waitFor(() => expect(button).toHaveClass("contained"));
    waitFor(() => expect(button).toHaveClass("color"));
  });
});

describe("Check that onclick fires correctly for AddTeamDialog", () => {
  it("should be error", () => {
    const wrapper = mount(<AddTeamDialog />);
    const button = wrapper.find("#error-button");
    // wait for them to render
    waitFor(() => expect(button).toHaveClass("contained"));
    waitFor(() => expect(button).toHaveClass("color"));
  });
});
