import React from "react";
import { GoogleMap, LoadScript, Marker, Circle } from "@react-google-maps/api";

// mui
import { makeStyles } from "@mui/styles";
import { TextField } from "@mui/material";
import Typography from "@mui/material/Typography";
import DatePicker from "@mui/lab/DatePicker";
import TimePicker from "@mui/lab/TimePicker";
import AdapterDateFns from "@mui/lab/AdapterDateFns";
import { LocalizationProvider } from "@mui/lab";
import Slider from "@mui/material/Slider";
import Input from "@mui/material/Input";

const useStyles = makeStyles((theme) => ({
  topInfoText: {
    justifyContent: "space-around",
    alignItems: "center",
    margin: "40px",
  },
  latlngInfoContainer: {
    display: "flex",
    height: "100px",
    width: "50%",
    justifyContent: "space-around",
    alignItems: "center",
  },
  relayInfoContainer: {
    display: "flex",
    minHeight: "650px",
    "@media (max-width: 780px)": {
      flexDirection: "column",
    },
  },

  leftCardContentContainer: {
    flex: "1",
    minHeight: "350px",
  },
  rightCardContentContainer: {
    display: "flex",
    flex: "1",
    flexDirection: "column",
    alignItems: "center",
  },
  rightCardInputFieldWidth: {
    width: "100%",
    maxWidth: "350px",
    marginBottom: "30px", // use this to adjust spacing.
  },
  radiusContainer: {
    display: "flex",
    width: "100%",
    maxWidth: "350px",
    marginBottom: "30px",
  },
}));

const mapContainerStyle = {
  height: "100%",
  minHeight: "350px",
  width: "100%",
};

// where google maps is initially.
const center = {
  lat: 59.911491,
  lng: 10.757933,
};

const RelayInfo = ({
  startLatitude,
  setStartLatitude,
  startLongitude,
  setStartLongitude,
  locationStartName,
  setLocationStartName,
  relayStartDate,
  setRelayStartDate,
  relayStartTime,
  setRelayStartTime,
  relayInformationText,
  setRelayInformationText,
  durationInHours,
  setDurationInHours,
  radius,
  setRadius,
  pushInterval,
  setPushInterval,
  editMode,
}) => {
  const classes = useStyles();

  const handleDatePickerClick = (newValue) => {
    setRelayStartDate(newValue);
  };

  const handleTimePickerClick = (newValue) => {
    setRelayStartTime(newValue);
  };

  const endDateText = () => {
    if (durationInHours > 0 && relayStartTime) {
      const placeHolderDate = new Date(relayStartTime);
      let endDate = new Date(
        placeHolderDate.getTime() + durationInHours * 60 * 60 * 1000
      );
      return `(${endDate.toTimeString()})`;
    }
    // blank text
    return <span>&#8203;</span>;
  };

  const handleRadiusChange = (e) => {
    setRadius(parseInt(e.target.value));
  };

  return (
    <div>
      <div className={classes.topInfoText}>
        <Typography align="center">
          Velg startposisjonen til løpet i kartet (vekslingssted) og fyll inn
          løpsinformasjonen før du går videre.
        </Typography>
      </div>
      <div className={classes.relayInfoContainer}>
        <div className={classes.leftCardContentContainer}>
          <LoadScript
            googleMapsApiKey={process.env.REACT_APP_GOOGLE_MAPS_API_KEY}
          >
            <GoogleMap
              id="marker-example"
              mapContainerStyle={mapContainerStyle}
              zoom={10}
              center={
                editMode ? { lat: startLatitude, lng: startLongitude } : center
              }
              onClick={(ev) => {
                setStartLatitude(ev.latLng.lat());
                setStartLongitude(ev.latLng.lng());
              }}
            >
              <Marker
                position={{
                  lat: startLatitude,
                  lng: startLongitude,
                }}
              />
              <Circle
                radius={radius}
                center={{ lat: startLatitude, lng: startLongitude }}
              />
            </GoogleMap>
          </LoadScript>
        </div>

        <div className={classes.rightCardContentContainer}>
          <Typography id="input-slider" gutterBottom>
            Radius for veksling (meter)
          </Typography>

          <div className={classes.radiusContainer}>
            <Slider
              value={typeof radius === "number" ? radius : 0}
              onChange={handleRadiusChange}
              aria-labelledby="input-slider"
              style={{ marginRight: "25px" }}
              min={20}
              max={1000}
            />
            <Input
              value={radius}
              sx={{ width: "70px" }}
              size="small"
              onChange={handleRadiusChange}
              //onBlur={handleBlur}
              inputProps={{
                min: 0,
                max: 999,
                type: "number",
                "aria-labelledby": "input-slider",
              }}
            />
          </div>

          <TextField
            className={classes.rightCardInputFieldWidth}
            variant="outlined"
            label="Sekunder mellom hver oppdatering i frontend"
            type="number"
            onChange={(e) => setPushInterval(parseInt(e.target.value))}
            value={pushInterval}
          />

          <TextField
            className={classes.rightCardInputFieldWidth}
            variant="outlined"
            label="Nærmeste stedsnavn på løp"
            value={locationStartName}
            onChange={(e) => setLocationStartName(e.target.value)}
          />

          <LocalizationProvider dateAdapter={AdapterDateFns}>
            <div className={classes.rightCardInputFieldWidth}>
              <DatePicker
                inputFormat="dd/MM/yyyy"
                label="Dato for løpets start"
                value={relayStartDate}
                onChange={handleDatePickerClick}
                renderInput={(params) => (
                  <TextField {...params} sx={{ width: "100%" }} />
                )}
              />
            </div>
            <div className={classes.rightCardInputFieldWidth}>
              <TimePicker
                ampm={false}
                label="Tidspunkt for løpets start"
                value={relayStartTime}
                onChange={handleTimePickerClick}
                renderInput={(params) => (
                  <TextField {...params} sx={{ width: "100%" }} />
                )}
              />
            </div>
          </LocalizationProvider>
          <TextField
            disabled={!relayStartTime}
            className={classes.rightCardInputFieldWidth}
            variant="outlined"
            label="Løpets varighet i timer"
            type="number"
            value={durationInHours}
            style={{ margin: "0" }}
            onChange={(e) => setDurationInHours(e.target.value)}
          />

          <p style={{ marginBottom: "30px" }}> {endDateText()}</p>

          <TextField
            className={classes.rightCardInputFieldWidth}
            variant="outlined"
            multiline
            rows={14}
            style={{ marginBottom: "0" }}
            placeholder="Tilleggsinformasjon om løpet"
            value={relayInformationText}
            onChange={(e) => setRelayInformationText(e.target.value)}
          />
        </div>
      </div>
    </div>
  );
};

export default RelayInfo;
