import { useState, useEffect } from "react";

// components
import CoordinateDialog from "../../CoordinateDialog";

// mui
import { Button } from "@mui/material";
import { makeStyles } from "@mui/styles";
import DeleteIcon from "@mui/icons-material/Delete";
import {
  FormLabel,
  FormGroup,
  FormControlLabel,
  Switch,
  List,
  ListItemButton,
  ListItem,
  ListItemText,
  IconButton,
  Menu,
  MenuItem,
  ListItemIcon,
} from "@mui/material";

const useStyles = makeStyles((theme) => ({
  newStageButtonContainer: {
    display: "flex",
    flexDirection: "column",
    alignItems: "center",
  },
  relaySwitchContainer: {
    display: "flex",
    flexDirection: "column",
    alignItems: "center",
  },
}));

const RelayStages = ({
  startLatitude,
  startLongitude,
  addRelayStage,
  circularRelay,
  setCircularRelay,
  relayStages,
  setRelayStages,
  removeStageClick,
  stageTypes,
}) => {
  const classes = useStyles();
  const [selectedStageIndex, setSelectedStageIndex] = useState(0);
  const [openStageDialog, setOpenStageDialog] = useState(false);
  const [dialogCoords, setDialogCoords] = useState({ lat: 0, lng: 0 });
  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);

  useEffect(() => {
    if (relayStages.length < 1) {
      //adds 4 default rely stages
      let relayStagesPlaceholder = [];
      for (let i = 0; i < 4; i++) {
        relayStagesPlaceholder.push({
          lat: startLatitude,
          lng: startLongitude,
          stageTypeIndex: i <= 1 ? 0 : 1,
        });
      }
      setRelayStages(relayStagesPlaceholder);
    }
  }, [relayStages, setRelayStages, startLatitude, startLongitude]);

  const stageTypeClick = (event, stageIndex) => {
    if (!anchorEl) {
      setSelectedStageIndex(stageIndex);
      setAnchorEl(event.currentTarget);
    }
  };

  const stageTypeClose = () => {
    setAnchorEl(null);
  };

  const handleModifyClick = (lat, lng) => {
    const placeholder = [...relayStages];
    placeholder[selectedStageIndex].lat = lat;
    placeholder[selectedStageIndex].lng = lng;
    setRelayStages(placeholder);

    handleListClose();
  };

  const handleListClose = () => {
    setOpenStageDialog(false);
  };

  const stageItemClick = (event, idx) => {
    if (circularRelay) {
      return;
    }

    setOpenStageDialog(true);
    setDialogCoords(relayStages[idx]);
    setSelectedStageIndex(idx);
  };

  const changeStageType = (stageTypeIndex) => {
    let relayStagesPlaceholder = [...relayStages];
    relayStagesPlaceholder[selectedStageIndex].stageTypeIndex = stageTypeIndex;
    setRelayStages(relayStagesPlaceholder);
    stageTypeClose();
  };

  return (
    <>
      <div className={classes.newStageButtonContainer}>
        <Button
          variant="contained"
          onClick={addRelayStage}
          style={{ marginBottom: "15px" }}
        >
          Legg til etappe
        </Button>
      </div>
      <div className={classes.relaySwitchContainer}>
        <FormLabel component="legend">Kun ett vekslingspunkt</FormLabel>
        <FormGroup>
          <FormControlLabel
            control={
              <Switch
                checked={circularRelay}
                disabled
                onChange={(event) => {
                  setCircularRelay(event.target.checked);
                }}
              />
            }
            label=""
          />
        </FormGroup>
      </div>

      <List sx={{ maxWidth: "650px", margin: "0 auto" }}>
        {relayStages.map((data, idx) => (
          <ListItem
            divider
            key={idx}
            secondaryAction={
              <IconButton edge="end" onClick={() => removeStageClick(idx)}>
                <DeleteIcon />
              </IconButton>
            }
          >
            <ListItemButton onClick={(event) => stageItemClick(event, idx)}>
              <div>
                <ListItemText
                  primary={
                    !circularRelay
                      ? `Etappe ${idx + 1}: Latitude: ${data.lat.toFixed(
                          3
                        )} Longitude: ${data.lng.toFixed(3)}`
                      : `Etappe ${
                          idx + 1
                        }: Vekslingspunkt er likt som startposisjon`
                  }
                />
              </div>
            </ListItemButton>

            <Button
              onClick={(e) => stageTypeClick(e, idx)}
              variant="contained"
              startIcon={stageTypes[data.stageTypeIndex].icon}
            >
              {stageTypes[data.stageTypeIndex].name}
            </Button>
            <Menu open={open} anchorEl={anchorEl} onClose={stageTypeClose}>
              {stageTypes.map((stageType, stageTypeIndex) => {
                const StageIcon = () => stageType.icon;

                return (
                  <MenuItem
                    key={stageTypeIndex}
                    onClick={() => changeStageType(stageTypeIndex)}
                  >
                    <ListItemIcon>
                      <StageIcon />
                    </ListItemIcon>
                    {stageType.name}
                  </MenuItem>
                );
              })}
            </Menu>
          </ListItem>
        ))}
      </List>

      <CoordinateDialog
        openDialog={openStageDialog}
        setOpenDialog={handleListClose}
        ModifyDataFunc={handleModifyClick}
        dialogTitle={`Modify Relay Stage ${selectedStageIndex + 1}`}
        valueLat={dialogCoords.lat}
        valueLng={dialogCoords.lng}
      />
    </>
  );
};

export default RelayStages;
