import React, { useEffect } from "react";
import { GoogleMap, LoadScript, Marker } from "@react-google-maps/api";
import { useState } from "react";
import {
  Dialog,
  DialogTitle,
  DialogContent,
  DialogActions,
  Button,
  TextField,
} from "@mui/material";

const mapContainerStyle = {
  height: "400px",
  width: "400px",
};

const CoordinateDialog = ({
  openDialog,
  setOpenDialog,
  ModifyDataFunc,
  dialogTitle,
  valueLat,
  valueLng,
}) => {
  const ModifyData = () => {
    ModifyDataFunc(lat, lng);
  };

  const handleClose = () => {
    setOpenDialog(false);
  };

  const [lat, setLat] = useState(0);

  const [lng, setLng] = useState(0);

  useEffect(() => {
    setLat(valueLat);
    setLng(valueLng);
  }, [valueLat, valueLng, openDialog]);

  return (
    <Dialog open={openDialog} keepMounted onClose={handleClose}>
      <DialogTitle>{dialogTitle}</DialogTitle>
      <DialogContent>
        <div>
          <TextField
            variant="outlined"
            placeholder="Latitude"
            value={lat.toFixed(3)}
            onChange={(e) => {
              setLat(e.target.value);
            }}
          />

          <TextField
            variant="outlined"
            placeholder="Longitude"
            value={lng.toFixed(3)}
            onChange={(e) => {
              setLng(e.target.value);
            }}
          />
        </div>

        <LoadScript
          googleMapsApiKey={process.env.REACT_APP_GOOGLE_MAPS_API_KEY}
        >
          <GoogleMap
            id="marker-example"
            mapContainerStyle={mapContainerStyle}
            zoom={10}
            center={{ lat: valueLat, lng: valueLng }}
            onClick={(ev) => {
              setLat(ev.latLng.lat());
              setLng(ev.latLng.lng());
            }}
          >
            <Marker
              position={{
                lat: lat,
                lng: lng,
              }}
            />
          </GoogleMap>
        </LoadScript>

        <DialogActions>
          <Button onClick={handleClose}>Cancel</Button>
          <Button onClick={ModifyData}>Modify</Button>
        </DialogActions>
      </DialogContent>
    </Dialog>
  );
};

export default CoordinateDialog;
