import { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import Loader from "../../components/Loader";
import MessageBox from "../../components/MessageBox";
import AddOrEditRelay from "../../components/AddOrEditRelay";
import { getRelayDetailFromAPI } from "../../utils/apiRequests";

const EditRelay = () => {
  const { id } = useParams();
  const [relayData, setRelayData] = useState([]);
  const [messageBox, setMessageBox] = useState({
    message: "",
    severity: "error",
  });

  useEffect(() => {
    getRelayDetailFromAPI(id)
      .then((relayDetailRes) => {
        setRelayData(relayDetailRes);
      })
      .catch((error) => {
        setMessageBox({ message: error.message, severity: "error" });
      });
  }, [id]);

  return (
    <>
      <Loader isLoading={relayData.length < 1}>
        <AddOrEditRelay editMode={true} relayData={relayData} relayId={id} />
      </Loader>
      <MessageBox messageBox={messageBox} setMessageBox={setMessageBox} />
    </>
  );
};

export default EditRelay;
