// mui
import Accordion from "@mui/material/Accordion";
import AccordionSummary from "@mui/material/AccordionSummary";
import AccordionDetails from "@mui/material/AccordionDetails";
import Typography from "@mui/material/Typography";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import IconButton from "@mui/material/IconButton";
import ContentCopyIcon from "@mui/icons-material/ContentCopy";
import { makeStyles } from "@mui/styles";
import DirectionsBikeIcon from "@mui/icons-material/DirectionsBike";
import DirectionsRunIcon from "@mui/icons-material/DirectionsRun";

const useStyles = makeStyles((theme) => ({
  componentContainer: {
    width: "100%",
  },
  accordionContainer: {
    display: "flex",
    alignItems: "flex-start",
    width: "100%",
  },
  accordion: {
    flex: 1,
  },
}));

const TeamList = ({ teams, stages }) => {
  const classes = useStyles();

  const copyInviteKey = (team) => {
    let stringToCopy = "";
    team.participants.map((p) => (stringToCopy += p.inviteKey + "\n"));
    navigator.clipboard.writeText(stringToCopy);
  };
  return (
    <div className={classes.componentContainer}>
      {Object.keys(teams).map((key, idx) => (
        <div className={classes.accordionContainer} key={idx}>
          <IconButton
            sx={{ marginTop: "20px" }}
            aria-label="copy"
            onClick={() => copyInviteKey(teams[key])}
          >
            <ContentCopyIcon />
          </IconButton>
          <div style={{ margin: "20px", width: "100%" }}>
            <Accordion className={classes.accordion}>
              <AccordionSummary
                expandIcon={<ExpandMoreIcon />}
                aria-controls={"panel-content" + idx}
                id={"panel-header" + idx}
              >
                <Typography>{teams[key].teamName}</Typography>
              </AccordionSummary>
              <AccordionDetails>
                {teams[key].participants.map((p, index) => (
                  <div>
                    <Typography>
                      Etappe {p.stageNumber}{" "}
                      {stages[index].stageTypeId === 1 ? (
                        <DirectionsRunIcon />
                      ) : (
                        <DirectionsBikeIcon />
                      )}
                    </Typography>
                    <Typography>Invitasjonkode: {p.inviteKey}</Typography>
                  </div>
                ))}
              </AccordionDetails>
            </Accordion>
          </div>
        </div>
      ))}
    </div>
  );
};

export default TeamList;
