import { useEffect, useState } from "react";
import { useParams } from "react-router-dom";
import { GoogleMap, LoadScript, Marker, Circle } from "@react-google-maps/api";
import { useNavigate } from "react-router-dom";
import CardBox from "../../components/CardBox";
import { getRelayDetailFromAPI } from "../../utils/apiRequests";
import { compare } from "../../utils/misc";
import Loader from "../../components/Loader";
import TeamList from "./components/TeamList";
import { dateToReadableString } from "../../utils/misc";
import MessageBox from "../../components/MessageBox";

// mui
import { Button, Typography } from "@mui/material";
import { makeStyles } from "@mui/styles";
import EditIcon from "@mui/icons-material/Edit";

const useStyles = makeStyles((theme) => ({
  relayInfoContainer: {
    display: "flex",
    minHeight: "650px",
  },
  addIconContainer: {
    display: "flex",
    flexDirection: "column",
    alignItems: "center",
  },
  leftCardContentContainer: {
    flex: "1",
  },
  rightCardContentContainer: {
    display: "flex",
    flex: "1",
    flexDirection: "column",
    alignItems: "center",
  },
}));

const mapContainerStyle = {
  height: "350px",
  width: "350px",
};

const RelayDetail = () => {
  const { id } = useParams();
  const classes = useStyles();
  const navigate = useNavigate();
  const [relayDetailData, setRelayDetailData] = useState({});
  const [messageBox, setMessageBox] = useState({
    message: "",
    severity: "error",
  });

  useEffect(() => {
    getRelayDetail();
  });

  const getRelayDetail = async () => {
    try {
      const relayDetailRes = await getRelayDetailFromAPI(id);

      // convert team with participants in better format
      let teamsPlaceholder = {};
      relayDetailRes.teams.map((team) => {
        team.participants = [];
        teamsPlaceholder[team.id] = team;
        return team;
      });

      relayDetailRes.participants.map((p) =>
        teamsPlaceholder[p.teamId].participants.push(p)
      );

      for (const key in teamsPlaceholder) {
        teamsPlaceholder[key].participants.sort((a, b) =>
          compare(a, b, "stageNumber")
        );
      }

      let relayDetailDataPlaceholder = { ...relayDetailRes };
      delete relayDetailDataPlaceholder.participants;
      relayDetailDataPlaceholder.teams = teamsPlaceholder;
      setRelayDetailData(relayDetailDataPlaceholder);
    } catch (error) {
      setMessageBox({ message: error.message, severity: "error" });
    }
  };

  const handleEditRelayClick = (id) => {
    navigate("/relay/" + id + "/edit");
  };
  return (
    <CardBox>
      <Loader isLoading={Object.keys(relayDetailData).length < 1}>
        <div>
          <div className={classes.addIconContainer} style={{ padding: "20px" }}>
            <Button
              variant="contained"
              size="medium"
              startIcon={<EditIcon fontSize="small" />}
              onClick={() => handleEditRelayClick(relayDetailData.id)}
            >
              Rediger løp
            </Button>
          </div>
          <div className={classes.relayInfoContainer}>
            <div className={classes.leftCardContentContainer}>
              <CardBox>
                <Typography variant="h6">{relayDetailData.location}</Typography>
                <Typography variant="body1">
                  {dateToReadableString(new Date(relayDetailData.startTime))} -{" "}
                  {dateToReadableString(
                    new Date(relayDetailData.endTime),
                    false,
                    true
                  )}
                </Typography>
                <Typography variant="body1">
                  {relayDetailData.information}
                </Typography>
              </CardBox>
              <CardBox>
                <Typography variant="body1">
                  Push Notification oppdatering vil skje hvert{" "}
                  {relayDetailData.frontendUpdateSeconds} sekund.
                </Typography>
                <LoadScript
                  googleMapsApiKey={process.env.REACT_APP_GOOGLE_MAPS_API_KEY}
                >
                  <GoogleMap
                    id="marker-example"
                    mapContainerStyle={mapContainerStyle}
                    zoom={10}
                    center={{
                      lat: relayDetailData.latitude,
                      lng: relayDetailData.longitude,
                    }}
                  >
                    <Marker
                      position={{
                        lat: relayDetailData.latitude,
                        lng: relayDetailData.longitude,
                      }}
                    />
                    <Circle
                      radius={relayDetailData.exchangeRadiusMeters}
                      center={{
                        lat: relayDetailData.latitude,
                        lng: relayDetailData.longitude,
                      }}
                    />
                  </GoogleMap>
                </LoadScript>
              </CardBox>
            </div>
            <div className={classes.rightCardContentContainer}>
              <TeamList
                teams={relayDetailData.teams}
                stages={relayDetailData.relayStages}
              />
            </div>
          </div>
        </div>
      </Loader>
      <MessageBox messageBox={messageBox} setMessageBox={setMessageBox} />
    </CardBox>
  );
};

export default RelayDetail;
