import React, { useEffect, useState } from "react";
import { Link } from "react-router-dom";
import { useNavigate } from "react-router-dom";
import { getAllRelays } from "../../utils/apiRequests";
import Loader from "../../components/Loader";
import CardBox from "../../components/CardBox";
import MessageBox from "../../components/MessageBox";

// mui
import {
  List,
  ListItemText,
  ListItemButton,
  ListItem,
  Button,
} from "@mui/material";
import AddIcon from "@mui/icons-material/Add";
import { makeStyles } from "@mui/styles";
import Divider from "@mui/material/Divider";
import ArrowForwardIosIcon from "@mui/icons-material/ArrowForwardIos";

const useStyles = makeStyles((theme) => ({
  list: {
    display: "flex",
    justifyContent: "space-around",
    alignItems: "center",
  },
  addIconContainer: {
    display: "flex",
    flexDirection: "column",
    alignItems: "center",
  },
}));

const RelayOverview = () => {
  const navigate = useNavigate();
  const classes = useStyles();
  const [relayData, setRelayData] = useState([]);
  const [messageBox, setMessageBox] = useState({
    message: "",
    severity: "error",
  });

  const handleListItemClick = (relay) => {
    navigate("/relay/" + relay.id);
  };

  useEffect(() => {
    const fetchData = async () => {
      try {
        const relays = await getAllRelays();
        setRelayData(relays);
      } catch (error) {
        setMessageBox({ message: error.message, severity: "error" });
      }
    };
    fetchData();
  }, []);

  return (
    <CardBox>
      <Loader isLoading={relayData.length < 1}>
        <div className={classes.addIconContainer} style={{ padding: "20px" }}>
          <Button
            variant="contained"
            size="medium"
            component={Link}
            to="/relay/new"
            startIcon={<AddIcon fontSize="small" />}
          >
            Legg til løp
          </Button>
        </div>
        <div className={classes.list}>
          <List style={{ overflow: "auto", width: "50%" }}>
            {relayData.map((relay, idx) => (
              <>
                <ListItem key={idx}>
                  <ListItemButton onClick={() => handleListItemClick(relay)}>
                    <ListItemText
                      primary={relay.location}
                      secondary={relay.information} // Make this date instead
                    />
                    <ArrowForwardIosIcon />
                  </ListItemButton>
                </ListItem>
                <Divider />
              </>
            ))}
          </List>
        </div>
      </Loader>
      <MessageBox messageBox={messageBox} setMessageBox={setMessageBox} />
    </CardBox>
  );
};

export default RelayOverview;
