import React, { useEffect, useState, useContext } from "react";
import Keycloak from "keycloak-js";

const AuthContext = React.createContext();

export const useAuth = () => {
  const context = useContext(AuthContext);
  if (context === undefined) {
    throw new Error("useAuth must be used within a AuthProvider");
  }
  return context;
};

export const AuthProvider = ({ children }) => {
  const [currentUser, setCurrentUser] = useState(null);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    // checks if user is logged in
    const keycloak = new Keycloak("/keycloak.json");
    keycloak.init({ onLoad: "check-sso" }).then((authenticated) => {
      if (authenticated) {
        // if logged in
        window.accessToken = keycloak.token;
        setCurrentUser(keycloak);
        setIsLoading(false);
      } else {
        setIsLoading(false);
      }
    });
  }, []);

  const logout = () => {
    var logoutOptions = {
      redirectUri: process.env.REACT_APP_LOGOUT_REDIRECT_URL,
    };
    currentUser.logout(logoutOptions);
  };

  if (isLoading) {
    return <>Laster...</>;
  }

  return (
    <AuthContext.Provider
      value={{
        currentUser,
        logout,
      }}
    >
      {children}
    </AuthContext.Provider>
  );
};
