import React from "react";
import ReactDOM from "react-dom";
import "./index.css";
import TeamsOverview from "./containers/TeamsOverview";
import NewRelay from "./containers/NewRelay";
import RelayDetail from "./containers/RelayDetail";
import Settings from "./containers/Settings";
import Login from "./containers/Login";
import EditRelay from "./containers/EditRelay";
import reportWebVitals from "./reportWebVitals";
import {
  BrowserRouter as Router,
  Route,
  Routes,
  Navigate,
} from "react-router-dom";
import Navbar from "./components/NavBar";
import RelayOverview from "./containers/RelayOverview";
import { AuthProvider, useAuth } from "./hooks/auth";

const AuthRoute = ({ children }) => {
  const auth = useAuth();
  if (!Boolean(auth.currentUser)) {
    return <Navigate to="/login" />;
  }
  return <>{children}</>;
};

const MainApp = () => {
  return (
    <AuthProvider>
      <Router>
        <Routes>
          <Route path="/login" element={<Login />} />
          <Route
            path="/"
            element={
              <AuthRoute>
                <Navbar />
                <Navigate to="/relay" />
              </AuthRoute>
            }
          />
          <Route
            exact
            path="/relay"
            element={
              <AuthRoute>
                <Navbar />
                <RelayOverview />
              </AuthRoute>
            }
          />
          <Route
            path="/relay/new"
            element={
              <AuthRoute>
                <Navbar />
                <NewRelay />
              </AuthRoute>
            }
          />
          <Route
            exact
            path="/relay/:id"
            element={
              <AuthRoute>
                <Navbar />
                <RelayDetail />
              </AuthRoute>
            }
          />
          <Route
            exact
            path="/relay/:id/edit"
            element={
              <AuthRoute>
                <Navbar />
                <EditRelay />
              </AuthRoute>
            }
          />
          <Route
            exact
            path="/team"
            element={
              <AuthRoute>
                <Navbar />
                <TeamsOverview />
              </AuthRoute>
            }
          />
          <Route
            exact
            path="/settings"
            element={
              <AuthRoute>
                <Navbar />
                <Settings />
              </AuthRoute>
            }
          />
        </Routes>
      </Router>
    </AuthProvider>
  );
};

ReactDOM.render(
  <React.StrictMode>
    <MainApp />
  </React.StrictMode>,
  document.getElementById("root")
);

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals();
