const axios = require("axios").default;
axios.interceptors.request.use(
  (config) => {
    const token = window.accessToken ? window.accessToken : "";
    config.headers["Authorization"] = "Bearer " + token;
    return config;
  },
  (error) => {
    Promise.reject(error);
  }
);

const APIURL = process.env.REACT_APP_API_URL;

const getAllTeamsFromAPI = async () => {
  try {
    const response = await axios.get(APIURL + "team");
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const getAllStageTypesFromAPI = async () => {
  try {
    const response = await axios.get(APIURL + "StageType");
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const createNewRelayToAPI = async (relayData) => {
  try {
    const response = await axios.post(APIURL + "Relay/new", relayData);
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const editRelayToAPI = async (relayData, id) => {
  try {
    const response = await axios.put(
      APIURL + "relay/" + id + "/edit",
      relayData
    );
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const getRelayDetailFromAPI = async (id) => {
  try {
    const response = await axios.get(APIURL + "relay/" + id);
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const getAllRelays = async () => {
  try {
    console.log(APIURL);
    const { data: response } = await axios.get(APIURL + "relay/");
    return response;
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const editTeamAPI = async (id, newTeam) => {
  // get what fields are present in the team object.
  let hasNewName = "TeamName" in newTeam;
  let hasNewEmail = "Email" in newTeam;

  if (hasNewName && hasNewEmail) {
    // both field are updated.
    try {
      const response = await axios.put(APIURL + `Team/${id}`, newTeam);
      if (response.status === 200) {
        return response.data;
      }
      throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
    } catch (error) {
      throw new Error(error.response.data);
    }
  } else if (hasNewName && !hasNewEmail) {
    let TeamName = newTeam.TeamName;
    newTeam = `[{"op":"replace","path":"TeamName","value":"${TeamName}"}]`;
    // new name but false for email
    try {
      const response = await axios.patch(
        APIURL + `Team/${id}`,
        JSON.parse(newTeam)
      );
      if (response.status === 200) {
        return response.data;
      }
      throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
    } catch (error) {
      throw new Error(error.response.data);
    }
  } else if (!hasNewName && hasNewEmail) {
    // no new name but new email.
    let Email = newTeam.Email;
    newTeam = `[{"op":"replace","path":"Email","value":"${Email}"}]`;
    try {
      const response = await axios.patch(
        APIURL + `Team/${id}`,
        JSON.parse(newTeam)
      );
      if (response.status === 200) {
        return response.data;
      }
      throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
    } catch (error) {
      throw new Error(error.response.data);
    }
  }
};

const deleteTeamApi = async (id) => {
  try {
    const response = await axios.delete(APIURL + `Team/${id}`);
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

const createNewTeamToAPI = async (teamData) => {
  try {
    const response = await axios.post(APIURL + "Team", teamData);
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Kunne ikke hente data fra API (men fikk kontakt)");
  } catch (error) {
    if (!error.status) {
      throw new Error("Nettverks problemer (ingen response fra API)");
    }
    throw new Error(error.response.data);
  }
};

export {
  getAllTeamsFromAPI,
  getAllStageTypesFromAPI,
  createNewRelayToAPI,
  editTeamAPI,
  getRelayDetailFromAPI,
  deleteTeamApi,
  createNewTeamToAPI,
  getAllRelays,
  editRelayToAPI,
};
