import React, { useState, useEffect } from "react";
import { StyleSheet } from "react-native";
import { View } from "native-base";
import Animated, {
  useSharedValue,
  useAnimatedStyle,
  interpolate,
  withTiming,
  Extrapolate,
  withRepeat,
  withDelay,
  Easing,
} from "react-native-reanimated";
import MaterialCommunityIcons from "react-native-vector-icons/MaterialCommunityIcons";

export default function Pulse({ stageType }) {
  const [pulse, setPulse] = useState([1, 2, 3]);

  const Pulse = ({ delay = 0, repeat = true }) => {
    const animation = useSharedValue(0);
    useEffect(() => {
      animation.value = withDelay(
        delay,
        withRepeat(
          withTiming(1, {
            duration: 1800,
            easing: Easing.linear,
          }),
          repeat ? -1 : 1,
          false
        )
      );
    }, []);
    const animatedStyles = useAnimatedStyle(() => {
      const opacity = interpolate(
        animation.value,
        [0, 1],
        [0.6, 0],
        Extrapolate.CLAMP
      );
      return {
        opacity: opacity,
        transform: [{ scale: animation.value }],
      };
    });
    return <Animated.View style={[styles.circle, animatedStyles]} />;
  };

  return (
    <View style={{ alignItems: "center", justifyContent: "center" }}>
      <View style={styles.innerCircle}>
        <MaterialCommunityIcons
          name={stageType === "Bike" ? "bike" : "run"}
          color={"white"}
          size={50}
        />
      </View>
      {pulse.map((item, index) => (
        <Pulse key={index} delay={300 * index} />
      ))}
    </View>
  );
}

const styles = StyleSheet.create({
  circle: {
    width: 350,
    borderRadius: 1000,
    height: 350,
    position: "absolute",
    borderColor: "#081c29",
    borderWidth: 4,
    backgroundColor: "#102e42",
  },

  innerCircle: {
    zIndex: 100,
    borderRadius: 1000,
    padding: 20,
    backgroundColor: "black",
  },
});
