import React, { useState } from "react";
import { StyleSheet } from "react-native";
import { Button, Center, Heading, Input, useToast, VStack } from "native-base";

export default function Landing({
  startTrackingWithInviteKey,
  setToastMessage,
}) {
  const [input, setInput] = useState("");
  const [isOpen, setIsOpen] = useState(false);
  const [isLoading, setIsLoading] = useState(false);

  const handleChange = (text) => setInput(text);
  const onClose = () => setIsOpen(false);

  const toast = useToast();
  const id = "error-toast";
  const cancelRef = React.useRef(null);

  const approve = async () => {
    if (input == "") {
      const message = ["Skriv inn invitasjonskoden"];
      setToastMessage([...message]);
      return;
    }
    onClose();
    setIsLoading(true);
    try {
      await startTrackingWithInviteKey(input);
    } catch (error) {
      setIsLoading(false);
    }
  };
  return (
    <VStack style={styles.container}>
      <Center>
        <Heading color={"white"} size="xl">
          Invitasjonskode
        </Heading>
      </Center>
      <Center style={styles.divide}>
        <Input
          borderColor="#fff"
          color="#fff"
          placeholderTextColor="#fff"
          input={input}
          w="300px"
          h="60px"
          size="2xl"
          placeholder="Invitasjonskode"
          onChangeText={handleChange}
        />
      </Center>
      <Center>
        <Button
          style={{ backgroundColor: "#102e42" }}
          isLoading={isLoading}
          w="300px"
          h="60px"
          onPress={approve}
        >
          Send
        </Button>
      </Center>
    </VStack>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: "center",
    justifyContent: "center",
  },
  divide: {
    marginTop: 20,
    marginBottom: 20,
  },
});
