import axios from "axios";
import { API_URL } from "@env";
import { getData } from "./storage";

const authorizeInviteKeyToAPI = async (inviteKey) => {
  let config = {
    headers: {
      Authorization: inviteKey,
    },
  };

  try {
    const response = await axios.post(
      API_URL + "Participant/authorize",
      {},
      config
    );
    if (response.status === 200) {
      return response.data;
    }
    throw new Error("Could not get data from API");
  } catch (error) {
    if (error.response) {
      throw new Error(error.response.data);
    }
    throw new Error("No connection to server - Check your internet connection");
  }
};

const postLocationToAPI = async (coords) => {
  try {
    let token = await getData();
    let body = {
      inviteKey: token,
      latitude: coords.latitude,
      longitude: coords.longitude,
    };
    const url = API_URL + "coordinate";
    const response = await axios.post(url, body);
  } catch (error) {
    console.log("Error sending location to api");
  }
};

export { authorizeInviteKeyToAPI, postLocationToAPI };
