﻿using BikeAndRunAPI.Services;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using System;

namespace BikeAndRunAPI.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class ParticipantController : Controller
    {
        public ParticipantService _participantService;
        private readonly ILogger _logger;

        public ParticipantController(ILogger<CoordinateController> logger, ParticipantService participantService)
        {
            _participantService = participantService;
            _logger = logger;
        }

        [HttpGet("{relayid}")]
        public IActionResult GetParticipantsByRelayId(long relayid)
        {
            try
            {
                var participants = _participantService.GetParticipantsByRelayId(relayid);
                return Ok(participants);
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }


        [HttpPost("authorize")]
        public IActionResult AuthorizeInviteKey()
        {
            var key = Request.Headers.TryGetValue("authorization", out var value);

            if (key)
            {
                try
                {
                    var mobileDisplayInfo = _participantService.AuthorizeInviteKey(value);
                    return Ok(mobileDisplayInfo);
                }
                catch (Exception ex)
                {
                    _logger.LogWarning(100, ex.Message);
                    return NotFound(ex.Message);
                }
            }
            else
            {
                _logger.LogWarning(100, "Mangler invitasjonskode");
                return NotFound("Mangler invitasjonskode");
            }
        }

    }
}
