﻿using BikeAndRunAPI.Jobs;
using BikeAndRunAPI.Services;
using BikeAndRunAPI.ViewModels;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using System;

namespace BikeAndRunAPI.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class RelayController : Controller
    {

        public PushRoutine _pushRoutine;
        public StartAndEndRaceRoutine _startAndEndRaceRoutine;
        public RelayService _relayService;
        private readonly ILogger _logger;

        public RelayController(ILogger<CoordinateController> logger, PushRoutine pushRoutine, RelayService relayService, StartAndEndRaceRoutine startAndEndRaceRoutine)
        {
            _pushRoutine = pushRoutine;
            _relayService = relayService;
            _startAndEndRaceRoutine = startAndEndRaceRoutine;
            _logger = logger;
        }

        // used for testing
        /*
        [HttpGet("{id}/start")]
        public IActionResult RoutineTest(long id)
        {
            _relayService.StartRelay(id);
            // _pushRoutine.StartPushRoutine(10, 1);
            return Ok();
        }
        */


        [HttpGet]
        public IActionResult GetAllRelays()
        {
            var allRelays = _relayService.GetAllRelays();
            if (allRelays == null)
            {
                return NotFound();
            }
            else
            {
                return Ok(allRelays);
            }
        }

        [HttpGet("{id}")]
        public IActionResult GetRelayById(long id)
        {
            try
            {
                var relayDetail = _relayService.GetRelayById(id);
                return Ok(relayDetail);

            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }

        }

        [Authorize]
        [HttpPut("{id}/edit")]
        public IActionResult EditRelay(NewOrEditRelayVM newRelayVM, long id)
        {
            try
            {
                _relayService.EditRelayById(newRelayVM, id);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }

        [Authorize]
        [HttpPost("new")]
        public IActionResult CreateNewRelay(NewOrEditRelayVM newRelayVM)
        {
            try
            {
                var relayId = _relayService.CreateNewRelay(newRelayVM);
                return Ok(relayId);
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return BadRequest(ex.Message);
            }

        }

        [Authorize]
        [HttpDelete("{id}")]
        public IActionResult DeleteRelayById(long id)
        {
            try
            {
                _relayService.DeleteRelayByRelayId(id);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }
    }
}
