﻿using BikeAndRunAPI.Services;
using BikeAndRunAPI.ViewModels;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.JsonPatch;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Logging;
using System;

namespace BikeAndRunAPI.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class TeamController : Controller
    {
        public TeamService _TeamService;
        private readonly ILogger _logger;
        public TeamController(ILogger<CoordinateController> logger, TeamService teamService)
        {
            _TeamService = teamService;
            _logger = logger;
        }

      //[Authorize]
        [HttpGet]
        public IActionResult GetAllTeams()
        {
            try
            {
                var allTeams = _TeamService.GetAllTeams();
                return Ok(allTeams);
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }

        [Authorize]
        [HttpPost]
        public IActionResult AddTeam(TeamVM team)
        {
            try
            {
                _TeamService.AddTeam(team);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }

        [Authorize]
        [HttpPut("{id}")]
        public IActionResult EditTeam(long id, TeamVM teamVM)
        {
            try
            {
                _TeamService.EditTeam(id, teamVM);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }

        [Authorize]
        [HttpPatch("{id}")]
        public IActionResult EditTeamPatch(long id, JsonPatchDocument team)
        {
            try
            {
                _TeamService.EditTeamPatch(id, team);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }

        [Authorize]
        [HttpDelete("{id}")]
        public IActionResult DeleteTeam(long id)
        {
            try
            {
                _TeamService.DeleteTeam(id);
                return Ok();
            }
            catch (Exception ex)
            {
                _logger.LogWarning(100, ex.Message);
                return NotFound(ex.Message);
            }
        }
    }
}
