﻿using BikeAndRunAPI.Scripts;
using Microsoft.AspNetCore.Builder;
using Microsoft.Extensions.DependencyInjection;
using System;
using System.Linq;

namespace BikeAndRunAPI.Data
{
    /// <summary>
    /// Initializes the database with some custom values. This is very useful in development when working so you can have some feedback to work with.
    /// </summary>
    public class DbInitializer
    {
        public static void Seed(IApplicationBuilder applicationBuilder)
        {
            using (var serviceScope = applicationBuilder.ApplicationServices.CreateScope())
            {
                var context = serviceScope.ServiceProvider.GetService<BikeAndRunContext>();

                if (!context.Teams.Any())
                {
                    context.Teams.AddRange(new Models.Team()
                    {
                        TeamName = "Headit AS",
                        Email = "koordinator@headit.no"
                    },
                    new Models.Team()
                    {
                        TeamName = "Norsk Tipping AS",
                        Email = "koordinator@norsktipping.no"
                    },
                    new Models.Team()
                    {
                        TeamName = "Helse Sør-Øst RHF",
                        Email = "koordinator@helsesorostrhf.no"
                    },
                    new Models.Team()
                    {
                        TeamName = "Moelven Industrier",
                        Email = "koordinator@moelvenindustrier.no"
                    });

                    context.SaveChanges();
                }

                /*
                if (!context.Coordinates.Any())
                {

                }
                */

                if (!context.Relays.Any())
                {
                    context.Relays.AddRange(new Models.Relay()
                    {
                        StartTime = DateTime.Now.AddDays(10),
                        EndTime = DateTime.Now.AddDays(10).AddHours(2),
                        Latitude = 60.796741,
                        Longitude = 10.694083,
                        Location = "Gjøvik stasjon",
                        Information = "Det er meldt regn så ta med ekstra skift.",
                        ExchangeRadiusMeters = 190,
                        FrontendUpdateSeconds = 10,
                        HasStarted = false,
                    },
                    new Models.Relay()
                    {
                        StartTime = DateTime.Now.AddDays(120),
                        EndTime = DateTime.Now.AddDays(10).AddHours(2),
                        Latitude = 60.794744,
                        Longitude = 11.067623,
                        Location = "Stortorget fontene",
                        Information = "Vennligst møt i god tid før start.",
                        ExchangeRadiusMeters = 190,
                        FrontendUpdateSeconds = 10,
                        HasStarted = false,
                    }); ;

                    context.SaveChanges();
                }

                if (!context.StageTypes.Any())
                {
                    context.StageTypes.AddRange(new Models.StageType()
                    {
                        Category = "Bike"
                    },
                    new Models.StageType()
                    {
                        Category = "Run"
                    });

                    context.SaveChanges();
                }

                if (!context.RelayStages.Any())
                {
                    context.RelayStages.AddRange(new Models.RelayStage()
                    {
                        RelayId = 1,
                        StageTypeId = 2,
                        StageNumber = 1,
                        EndLatitude = 60.796741,
                        EndLongitude = 10.694083
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 1,
                        StageTypeId = 2,
                        StageNumber = 2,
                        EndLatitude = 60.796741,
                        EndLongitude = 10.694083
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 1,
                        StageTypeId = 1,
                        StageNumber = 3,
                        EndLatitude = 60.796741,
                        EndLongitude = 10.694083
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 1,
                        StageTypeId = 2,
                        StageNumber = 4,
                        EndLatitude = 60.796741,
                        EndLongitude = 10.694083
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 2,
                        StageTypeId = 1,
                        StageNumber = 1,
                        EndLatitude = 60.794744,
                        EndLongitude = 11.067623
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 2,
                        StageTypeId = 2,
                        StageNumber = 2,
                        EndLatitude = 60.794744,
                        EndLongitude = 11.067623
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 2,
                        StageTypeId = 1,
                        StageNumber = 3,
                        EndLatitude = 60.794744,
                        EndLongitude = 11.067623
                    },
                    new Models.RelayStage()
                    {
                        RelayId = 2,
                        StageTypeId = 2,
                        StageNumber = 4,
                        EndLatitude = 60.794744,
                        EndLongitude = 11.067623
                    });

                    context.SaveChanges();
                }

                if (!context.Participants.Any())
                {
                    context.Participants.AddRange(new Models.Participant()
                    {
                        TeamId = 1,
                        RelayStageId = 1,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 1,
                        RelayStageId = 2,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 1,
                        RelayStageId = 3,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 1,
                        RelayStageId = 4,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = true,
                    },
                    new Models.Participant()
                    {
                        TeamId = 2,
                        RelayStageId = 1,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 2,
                        RelayStageId = 2,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 2,
                        RelayStageId = 3,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 2,
                        RelayStageId = 4,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = true,
                    },
                    new Models.Participant()
                    {
                        TeamId = 3,
                        RelayStageId = 1,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 3,
                        RelayStageId = 2,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 3,
                        RelayStageId = 3,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 3,
                        RelayStageId = 4,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = true,
                    },
                    new Models.Participant()
                    {
                        TeamId = 4,
                        RelayStageId = 1,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 4,
                        RelayStageId = 2,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 4,
                        RelayStageId = 3,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = false,
                    },
                    new Models.Participant()
                    {
                        TeamId = 4,
                        RelayStageId = 4,
                        InviteKey = Generator.RandomString(6),
                        HasJoined = false,
                        IsInRacingStage = true,
                    });

                    context.SaveChanges();
                }
            }
        }

        // only for development
        public static void CreateCleanDb(IApplicationBuilder applicationBuilder)
        {
            using (var serviceScope = applicationBuilder.ApplicationServices.CreateScope())
            {
                /*
                var context = serviceScope.ServiceProvider.GetService<BikeAndRunContext>();
                
                if (context.LiveCoordinate.Any())
                {
                    var itemsToDelete = context.Set<LiveCoordinate>();
                    context.LiveCoordinate.RemoveRange(itemsToDelete);
                    context.SaveChanges();
                }
                */
            }
        }
    }
}
