﻿using BikeAndRunAPI.Data;
using BikeAndRunAPI.Data.DTO;
using System;
using System.Collections.Generic;
using System.Linq;

namespace BikeAndRunAPI.Services
{
    public class ParticipantService
    {
        private readonly BikeAndRunContext _context;

        public ParticipantService(BikeAndRunContext context)
        {
            _context = context;
        }

        /// <summary>
        /// Fetches participants to display them list-wise on front end.
        /// </summary>
        /// <param name="relayId">relay to fetch participants froms</param>
        /// <returns>List of participants</returns>
        public List<ParticipantDTO> GetParticipantsByRelayId(long relayId)
        {
            var participants = (from participant in _context.Participants
                                join team in _context.Teams on participant.TeamId equals team.Id
                                join relayStage in _context.RelayStages on participant.RelayStageId equals relayStage.Id
                                where relayStage.RelayId.Equals(relayId)
                                select new
                                {
                                    Id = participant.Id,
                                    TeamId = participant.TeamId,
                                    TeamName = team.TeamName,
                                    RelayStageId = participant.RelayStageId,
                                    StageNumber = relayStage.StageNumber,
                                    InviteKey = participant.InviteKey,
                                    IsInRacingStage = participant.IsInRacingStage,
                                }).ToList();

            List<ParticipantDTO> participantsDTO = participants.Select(p => new ParticipantDTO()
            {
                Id = p.Id,
                TeamId = p.TeamId,
                TeamName = p.TeamName,
                RelayStageId = p.RelayStageId,
                StageNumber = p.StageNumber,
                InviteKey = p.InviteKey,
                HasJoined = false,
                IsInRacingStage = p.IsInRacingStage,
            }).ToList();
            return participantsDTO;
        }

        /// <summary>
        /// Authorises/checks that mobile input was present in database.
        /// </summary>
        /// <param name="inputKey">Key to check against</param>
        /// <returns>structure to be displayed on mobile device</returns>
        /// <exception cref="Exception">thrown if the invite key inputted is not in the database</exception>
        public MobileResponseDTO AuthorizeInviteKey(string inputKey)
        {
            var participant = _context.Participants.FirstOrDefault(p => p.InviteKey == inputKey);
            if (participant == null)
            {
                throw new Exception("Ikke gyldig invitasjonsskode. Prøv igjen");
            }

            var team = _context.Teams.FirstOrDefault(t => t.Id == participant.TeamId);
            var relayStage = _context.RelayStages.FirstOrDefault(rs => rs.Id == participant.RelayStageId);
            var stageType = _context.StageTypes.FirstOrDefault(st => st.Id == relayStage.StageTypeId);

            MobileResponseDTO mobileDisplayInfoDTO = new MobileResponseDTO()
            {
                TeamName = team.TeamName,
                StageNumber = relayStage.StageNumber,
                StageType = stageType.Category
            };

            return mobileDisplayInfoDTO;
        }
    }
}
