﻿using BikeAndRunAPI.Controllers;
using BikeAndRunAPI.Data;
using BikeAndRunAPI.Data.Models;
using BikeAndRunAPI.Services;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Data.Sqlite;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.Logging;
using Moq;
using System;
using System.Collections.Generic;
using System.Data.Common;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xunit;
using Xunit.Abstractions;

namespace IntegrationTests
{
    public class ParticipantIntegrationTests
    {
        private readonly DbConnection connection;
        private readonly DbContextOptions<BikeAndRunContext> dbContextOptions;
        private ParticipantService participantService;


        private readonly Mock<ILogger<CoordinateController>> logger = null; // we do not use this for tests but we have to create it as controllers demand it.

        private readonly ITestOutputHelper output; // use the method output.Writeline to print state in tests.


        public ParticipantIntegrationTests(ITestOutputHelper output)
        {
            connection = new SqliteConnection("Filename=:memory:");
            connection.Open();

            logger = new Mock<ILogger<CoordinateController>>();
            logger.Setup(x => x.Log<It.IsAnyType>(
                It.IsAny<LogLevel>(), It.IsAny<EventId>(), It.IsAny<It.IsAnyType>(), It.IsAny<Exception>(), (Func<It.IsAnyType, Exception, string>)It.IsAny<object>()));

            dbContextOptions = new DbContextOptionsBuilder<BikeAndRunContext>().UseSqlite(connection).Options;

            using var ctx = new BikeAndRunContext(dbContextOptions);

            ctx.Database.EnsureCreated();

            ctx.AddRange(
                new Participant()
                {
                    InviteKey = "A1B2C3",
                    Team = new Team()
                    {
                        TeamName = "Team1",
                        Email = "Team1@gmail.com"
                    },
                    RelayStageId = 2,
                    RelayStage = new RelayStage()
                    {
                        RelayId = 1,
                        Relay = new Relay()
                        {
                            StartTime = new DateTime(2012, 12, 12),
                            EndTime = new DateTime(2012, 12, 13),
                            Latitude = 60.79574,
                            Longitude = 10.69155,
                            Location = "Gjøvik",
                            Information = "Ta med ekstra sokker og et sett med skift",
                            ExchangeRadiusMeters = 30,
                            FrontendUpdateSeconds = 3,
                            HasStarted = false
                        },
                        StageTypeId = 1,
                        StageType = new StageType()
                        {
                            Category = "Bike",
                        },
                        StageNumber = 1,
                        EndLatitude = 100,
                        EndLongitude = 100,
                    },
                    IsInRacingStage = false,
                    HasJoined = true,
                }
                );
            ctx.SaveChanges();

            this.output = output;
        }

        private BikeAndRunContext CreateContext() => new(dbContextOptions);

        internal void DisposeContext() => connection.Dispose();

        [Fact]
        public void TestGettingParticipantById()
        {
            using var ctx = CreateContext();
            participantService = new ParticipantService(ctx);

            var controller = new ParticipantController(logger.Object, participantService);

            var participant = controller.GetParticipantsByRelayId(1);

            var okResult = participant as OkObjectResult;

            Assert.NotNull(okResult);
            Assert.Equal(200, okResult.StatusCode);

            DisposeContext();
        }
    }
}
