## About The Project
BikeAndRun backend is a REST api written in C# using .NET and ASP.NET that drives the application with data to the front end using SignalR Websockets.

### Built With

* [.NET](https://dotnet.microsoft.com/en-us/)
* [Asp.Net](https://dotnet.microsoft.com/en-us/apps/aspnet)
	* [SignalR](https://dotnet.microsoft.com/en-us/apps/aspnet/signalr)

## Getting Started

This is an example of how you may give instructions on setting up your project locally.
To get a local copy up and running follow these simple example steps.

### Prerequisites

This has to be installed to be able to run the application locally.

.NET 6 introduces some breaking changes with our application which is written with .NET 5 packages, so we advise to use .NET 5 but .NET 6 might work as well.

 * .NET Core SDK (x64 windows installer)  
	  ```sh
	  https://dotnet.microsoft.com/en-us/download/dotnet/thank-you/sdk-5.0.407-windows-x64-installer
	  ```
 * .ASP NET Runtime (x64 windows installer)  
	  ```
	 https://dotnet.microsoft.com/en-us/download/dotnet/thank-you/runtime-aspnetcore-5.0.16-windows-x64-installer
	  ```
      
### Installation

1. Clone the repo
   ```sh
   git clone https://YOUR_USERNAME@bitbucket.org/headit/bike-and-run-backend.git
   ```
2. Configure a file called `appsettings.json`. This is custom per deployment, you need to configure the connection to the database, that is the only thing you must modify (DefaultConnectionString). This file needs to be placed in the root folder of the project.
[At this site you can find all types of connection strings](https://www.connectionstrings.com/sql-server/)
```json
{
  "Logging": {
    "LogLevel": {
      "Default": "Information",
      "Microsoft": "Warning",
      "Microsoft.Hosting.Lifetime": "Information"
    }
  },
  "AllowedHosts": "*",
  "ConnectionStrings": {
    "DefaultConnectionString": "Server=tcp:YOUR_DATABASE_SERVER_NAME,1433;
                                Initial Catalog=YOUR_CATALOG_NAME;
                                Persist Security Info=False;
                                User ID=USER_ID;
                                Password=USER_PASSWORD;
                                MultipleActiveResultSets=False;
                                Encrypt=True;
                                TrustServerCertificate=False;
                                Connection Timeout=30;"
  },
  "Keycloak": {
    "ServerRealm": "KEYCLOAK_REALM_URL",
    "Metadata": "KEYCLOAK_OPENID_CONFIGURATION_URL",
    "ClientId": "CLIENT_ID",
    "ClientSecret": "CLIENT_SECRET"
  }
}
```
#### Running the app
In the repo we provide a solution file, we recommend using visual studio to run the project because of the extremely well C# compatiability.

If you want you can also run the project directly from the command line using the ```dotnet run``` command in the root of the project.

Documentation has been generated using doxygen, this can be found in the root folder.

You can also run the project in a docker environment.

``` docker build -t YOUR_REST_API_NAME```  
``` docker run -d -p 8080:80 YOUR_APP_NAME .```

## Usage
The api uses swaggerdoc to generate a page which allows you to run the data against the endpoints right away. It will also display the schema for the database setup at the bottom. You can use this for testing and in development to quickly view results.

Another option is to use Postman, where the only minor setback is that you need to input all of the endpoint URLs yourself, but we recommend creating a collection of requests and having those easily availbable through that collection. You can copy paste all the URLs form the swaggerdoc page as it generates those from attributes set in the code.

## Tests
In the repo there are two projects that are a part of the solution which are dedicated to testing. We recommend using the test explorer/test runner in visual studio to run these tests.
Otherwise you can use the dotnet cli command ```dotnet test```

[Here is a short tutorial on how to use the test explorer by microsoft](https://docs.microsoft.com/en-us/visualstudio/test/run-unit-tests-with-test-explorer?view=vs-2022)

## API Documentation

## Coordinate
### /api/Coordinate
**Request:**
```json
POST HTTP/1.1
Content-Type: application/json
{
    "username": "foo",
    "password": "1234567" 
}
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json

{
}
```
**Failed Response:**
```json
HTTP/1.1 400 Undocumeneted
Content-Type: text/plain
{
    Ikke gyldig invitasjonskode
}
``` 


## Participant
### /api/Participant{relayid}
**Request:**
```json
GET HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
[
  {
    "id": 1,
    "teamId": 2,
    "teamName": "Norsk Tipping AS",
    "relayStageId": 4,
    "stageNumber": 1,
    "inviteKey": "GC9K6H",
    "hasJoined": false,
    "isInRacingStage": true
  },
  ...
]
```

### /api/Participant/authorize
**Request:**
Invite key is given in header for this request


## Relay
### /api/Relay
**Request:**
```json
GET HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
[
  {
    "id": 1,
    "startTime": "2022-09-13T12:27:48.0927026",
    "endTime": "2022-05-26T14:27:48.0927039",
    "latitude": 60.794744,
    "longitude": 11.067623,
    "location": "Stortorget fontene",
    "information": "Vennligst møt i god tid før start.",
    "exchangeRadiusMeters": 190,
    "frontendUpdateSeconds": 10,
    "hasStarted": false
  },
  ...
```

### /api/Relay/{relayid}
**Request:**
```json
GET HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
{
  "id": 1,
  "latitude": 60.794744,
  "longitude": 11.067623,
  "location": "Stortorget fontene",
  "startTime": "2022-09-13T12:27:48.0927026",
  "endTime": "2022-05-26T14:27:48.0927039",
  "information": "Vennligst møt i god tid før start.",
  "circularRelay": false,
  "exchangeRadiusMeters": 190,
  "frontendUpdateSeconds": 10,
  "hasStarted": false,
  "participants": [
    {
      "id": 1,
      "teamId": 2,
      "teamName": "Norsk Tipping AS",
      "relayStageId": 4,
      "stageNumber": 1,
      "inviteKey": "GC9K6H",
      "hasJoined": false,
      "isInRacingStage": true
    },
    {
      "id": 2,
      "teamId": 2,
      "teamName": "Norsk Tipping AS",
      "relayStageId": 3,
      "stageNumber": 2,
      "inviteKey": "ZN2WX4",
      "hasJoined": false,
      "isInRacingStage": false
    },
    ...
  ],
  "teams": [
    {
      "id": 1,
      "teamName": "Headit AS",
      "email": "koordinator@headit.no"
    },
    {
      "id": 2,
      "teamName": "Norsk Tipping AS",
      "email": "koordinator@norsktipping.no"
    },
   ...
  ],
  "relayStages": [
    {
      "stageTypeId": 2,
      "endLatitude": 60.796741,
      "endLongitude": 10.694083
    },
    {
      "stageTypeId": 1,
      "endLatitude": 60.796741,
      "endLongitude": 10.694083
    },
    {
      "stageTypeId": 2,
      "endLatitude": 60.796741,
      "endLongitude": 10.694083
    },
    ...
  ]
}
```
**Failed Response:**
```json
HTTP/1.1 404 Not Found
Content-Type: text/plain
{
    Fant ikke løp
}
``` 

### /api/Relay/{id}
**Request:**
```json
DELETE HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```
**Failed Response:**
```json
HTTP/1.1 404 Not Found
Content-Type: text/plain
{
    Fant ikke løp
}
```

### /api/Relay/{id}/edit
**Request:**
```json
PUT HTTP/1.1
Content-Type: application/json
{
  "latitude": 0,
  "longitude": 0,
  "location": "string",
  "startTime": "2022-05-19T07:40:09.711Z",
  "endTime": "2022-05-19T07:40:09.711Z",
  "information": "string",
  "circularRelay": true,
  "exchangeRadiusMeters": 0,
  "frontendUpdateSeconds": 0,
  "teamIds": [
    0
  ],
  "relayStages": [
    {
      "stageTypeId": 0,
      "lat": 0,
      "lng": 0
    }
  ]
}
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```
**Failed Response:**
```json
HTTP/1.1 404 Not Found
Content-Type: text/plain
{
    Fant ikke løp
}
```

### /api/Relay/new
**Request:**
```json
POST HTTP/1.1
Content-Type: application/json
{
  "latitude": 0,
  "longitude": 0,
  "location": "string",
  "startTime": "2022-05-19T07:40:09.711Z",
  "endTime": "2022-05-19T07:40:09.711Z",
  "information": "string",
  "circularRelay": true,
  "exchangeRadiusMeters": 0,
  "frontendUpdateSeconds": 0,
  "teamIds": [
    0
  ],
  "relayStages": [
    {
      "stageTypeId": 0,
      "lat": 0,
      "lng": 0
    }
  ]
}
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```

## StageType
### /api/Stagetype
**Request:**
```json
GET HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
[
  {
    "id": 1,
    "category": "Run"
  },
  {
    "id": 2,
    "category": "Bike"
  }
]
```

## Team
### /api/Team
**Request:**
```json
GET HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
[
  {
    "id": 1,
    "teamName": "Headit AS",
    "email": "koordinator@headit.no"
  },
  {
    "id": 2,
    "teamName": "Norsk Tipping AS",
    "email": "koordinator@norsktipping.no"
  },
  {
    "id": 3,
    "teamName": "Helse Sør-Øst RHF",
    "email": "koordinator@helsesorostrhf.no"
  },
  {
    "id": 4,
    "teamName": "Moelven Industrier",
    "email": "koordinator@moelvenindustrier.no"
  }
]
```

### /api/Team
**Request:**
```json
POST HTTP/1.1
Content-Type: application/json
  {
    "teamName": "Moelven Industrier",
    "email": "koordinator@moelvenindustrier.no"
  }
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```

### /api/Team/{id}
**Request:**
```json
PUT HTTP/1.1
Content-Type: application/json
  {
    "teamName": "Moelven Industrier",
    "email": "koordinator@moelvenindustrier.no"
  }
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```

### /api/Team/{id}
**Request:**
```json
PATCH HTTP/1.1
Content-Type: application/json
[
  {
    "operationType": 0,
    "path": "string",
    "op": "string",
    "from": "string"
  }
]
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```

### /api/Team/{id}
**Request:**
```json
DELETE HTTP/1.1
Content-Type: application/json
```
**Successful Response:**
```json
HTTP/1.1 200 OK
Content-Type: application/json
```

**Failed Response:**
```json
HTTP/1.1 404 Not Found
Content-Type: text/plain
{
    Fant ikke team med id: {id from parameter}
}
```

```json
HTTP/1.1 404 Not Found
Content-Type: text/plain
{
    Kan ikke slette team som har participant koblet til teamet.
}
```