import React from "react";
import { GoogleMap, useJsApiLoader, Marker } from "@react-google-maps/api";

import mapStyles from "../../mapStyles.json";

const containerStyle = {
  width: "100%",
  height: "100%",
};

const mapOptionsStyle = {
  styles: mapStyles,
};

const defaultZoom = 14;
const MapDisplay = ({ coordinates, center }) => {
  const { isLoaded } = useJsApiLoader({
    id: "google-map-script",
    googleMapsApiKey: process.env.REACT_APP_GOOGLE_MAPS_API_KEY,
  });

  return isLoaded ? (
    <div style={{ height: "100%", display: "flex", flexDirection: "column" }}>
      <div style={{ height: "100%" }}>
        <GoogleMap
          mapContainerStyle={containerStyle}
          center={center}
          zoom={defaultZoom}
          options={mapOptionsStyle}
        >
          {Object.keys(coordinates).map((teamName, idx) => {
            const teamCoordinates = coordinates[teamName];
            return (
              <Marker
                position={{
                  lat: teamCoordinates[0].lat,
                  lng: teamCoordinates[0].lng,
                }}
                key={idx}
                icon={{
                  url: "http://maps.google.com/mapfiles/ms/icons/blue.png",
                  scaledSize: new window.google.maps.Size(35, 35),
                  labelOrigin: new window.google.maps.Point(15, -11),
                }}
                label={{
                  text:
                    `${teamName}` + `${" " + teamCoordinates[0].stageNumber}`,
                  fontSize: "13px",
                  padding: "7px",
                }}
              />
            );
          })}
        </GoogleMap>
      </div>
    </div>
  ) : (
    <div>408 - Request Timeout on Map load</div>
  );
};

export default MapDisplay;
