import React, { useEffect, useState } from "react";
import MapDisplay from "../../components/MapDisplay/index";
import { getAllRelays } from "../../utils";
import RelayListDialog from "./components/RelayListDialog";
import { HubConnectionBuilder } from "@microsoft/signalr";

const Landing = () => {
  const [hubConnection, setHubConnection] = useState();
  const [coordinates, setCoordinates] = useState({});
  const [relays, setRelays] = useState([]);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState("");
  const [selectedRelayId, setSelectedRelayId] = useState(-1);
  const [openRelayListDialog, setOpenRelayListDialog] = useState(false);
  const [center, setCenter] = useState({ lat: 0, lng: 0 });
  const secondsBeforeRetryConnect = 2;

  useEffect(() => {
    //createHubConnection();
    const fetchRelays = async () => {
      try {
        const relaysPlaceholder = await getAllRelays();
        setRelays(relaysPlaceholder);
        setOpenRelayListDialog(true);
        setIsLoading(false);
      } catch (error) {
        setError("Could not connect to API");
      }
    };
    fetchRelays();
  }, []);

  useEffect(() => {
    if (hubConnection && selectedRelayId > 0) {
      hubConnection.on(
        "Coordinates-RelayId" + selectedRelayId,
        (coordinatesFromAPI) => {
          let coordinatesPlaceholder = {};
          coordinatesFromAPI.forEach((c) => {
            if (!coordinatesPlaceholder[c.teamName]) {
              coordinatesPlaceholder[c.teamName] = [
                {
                  lat: c.latitude,
                  lng: c.longitude,
                  timestamp: c.timestamp,
                  stageNumber: c.stageNumber,
                },
              ];
            } else {
              coordinatesPlaceholder[c.teamName].push({
                lat: c.latitude,
                lng: c.longitude,
                timestamp: c.timestamp,
                stageNumber: c.stageNumber,
              });
            }
          });
          setCoordinates(coordinatesPlaceholder);
        }
      );
    }
  }, [hubConnection, selectedRelayId]);

  const createHubConnection = async (relayId) => {
    setSelectedRelayId(relayId);
    let relay = relays.find((o) => o.id === relayId);
    const centerPlaceholder = { lat: relay.latitude, lng: relay.longitude };
    setCenter(centerPlaceholder);

    const hubConnection = new HubConnectionBuilder()
      .withUrl(process.env.REACT_APP_WEB_SOCKET_URL)
      .build();
    try {
      await hubConnection.start();
      setHubConnection(hubConnection);
    } catch (e) {
      console.log("error", e);
      console.log(
        "tryng to connect again in " + secondsBeforeRetryConnect + " seconds..."
      );
      setTimeout(() => {
        createHubConnection(relayId);
      }, secondsBeforeRetryConnect * 1000);
    }
  };

  return (
    <div style={{ height: "100%" }}>
      {isLoading ? (
        <>{error.length > 0 ? <div>{error}</div> : <div>Laster...</div>}</>
      ) : (
        <>
          {relays.length >= 1 ? (
            <MapDisplay coordinates={coordinates} center={center} />
          ) : (
            <div>Fant ingen løp</div>
          )}
        </>
      )}
      <RelayListDialog
        openRelayListDialog={openRelayListDialog}
        setOpenRelayListDialog={setOpenRelayListDialog}
        relays={relays}
        createHubConnection={createHubConnection}
      />
    </div>
  );
};

export default Landing;
